Colour - HDRI — Colour - HDRI 0.1.0 documentation

# Colour - HDRI

A Python package implementing various HDRI / Radiance image processing algorithms.

It is open source and freely available under the New BSD License terms.

## Features

## Installation

## Usage

The main reference for Colour - HDRI is the complete sphinx API Reference:

- API Reference

- colour_hdri Package
  - Sub-Packages
    - colour_hdri.calibration Package
      - Sub-Modules
        - colour_hdri.calibration.debevec1997 Module
          - Debevec (1997) Camera Response Function Computation
      - Module Contents
    - colour_hdri.generation Package
      - Sub-Modules
        - colour_hdri.generation.radiance Module
          - HDRI / Radiance Image Generation
        - colour_hdri.generation.weighting_functions Module
          - Weighting Functions
      - Module Contents
    - colour_hdri.models Package
      - Sub-Modules
        - colour_hdri.models.rgb Module
          - RGB Colourspace & Transformations
      - Module Contents
    - colour_hdri.plotting Package
      - Sub-Modules
        - colour_hdri.plotting.radiance Module
          - HDRI / Radiance Image Plotting
      - Module Contents
    - colour_hdri.process Package
      - Sub-Modules
        - colour_hdri.process.conversion Module
          - Conversion Process
      - Module Contents
    - colour_hdri.recovery Package
      - Sub-Modules
        - colour_hdri.recovery.highlights Module
          - Clipped Highlights Recovery
      - Module Contents
    - colour_hdri.sampling Package
      - Sub-Modules
        - colour_hdri.sampling.grossberg2003 Module
          - Grossberg (2003) Histogram Based Image Sampling
      - Module Contents
    - colour_hdri.tonemapping Package
      - Sub-Packages
        - colour_hdri.tonemapping.global_operators Package
          - Sub-Modules
            - colour_hdri.tonemapping.global_operators.operators Module
              - Global Tonemapping Operators
          - Module Contents
      - Module Contents
    - colour_hdri.utilities Package
      - Sub-Modules
        - colour_hdri.utilities.common Module
          - Common Utilities
        - colour_hdri.utilities.exif Module
          - EXIF Manipulation
        - colour_hdri.utilities.exposure Module
          - Image Exposure Value Computation
        - colour_hdri.utilities.image Module
          - Image Data & Metadata Utilities
      - Module Contents
  - Module Contents
    - Colour - HDRI
      - Subpackages

## Contributing

If you would like to contribute to Colour - HDRI, please refer to the following Contributing guide for Colour.

## Bibliography

The bibliography is available in the repository in either BibTeX format or reStructuredText.

## About

Colour - HDRI by Colour Developers - 2015
Copyright © 2015 – Colour Developers – colour-science@googlegroups.com
This software is released under terms of New BSD License: http://opensource.org/licenses/BSD-3-Clause
http://github.com/colour-science/colour-hdri